SystemContactPickerPlatform class abstract

Contract implemented by platform-specific contact picker integrations.

Inheritance
  • Object
  • PlatformInterface
  • SystemContactPickerPlatform
Implementers

Constructors

SystemContactPickerPlatform()
Constructs a SystemContactPickerPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCapabilities() Future<ContactPickerCapabilities>
Returns capabilities exposed by the platform implementation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickContacts({required Set<ContactField> fields, required bool allowMultiple, required int? limit, required bool matchAllFields}) Future<List<PickedContact>>
Opens the platform contact picker with the requested options.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SystemContactPickerPlatform
The default instance of SystemContactPickerPlatform to use.
getter/setter pair