MethodChannelSystemContactPicker class
An implementation of SystemContactPickerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- SystemContactPickerPlatform
- MethodChannelSystemContactPicker
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCapabilities(
) → Future< ContactPickerCapabilities> -
Returns capabilities exposed by the platform implementation.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickContacts(
{required Set< ContactField> fields, required bool allowMultiple, required int? limit, required bool matchAllFields}) → Future<List< PickedContact> > -
Opens the platform contact picker with the requested options.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited